@@ -1,9 +1,10 @@
 #ifndef __TXT2GAL_H
-#  define __TXT2GAL_H
+# define __TXT2GAL_H
 /*
 *  txt2gcal.h:  Creates a verbatim Gcal resource file from a text file header file.
 *
 *
+*  Copyright (c) 2000-2010 Free Software Foundation, Inc.
 *  Copyright (c) 1996, 1997, 2000 Thomas Esken
 *
 *  This software doesn't claim completeness, correctness or usability.
@@ -14,15 +15,12 @@
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the `GNU General Public License' as published by
-*  the `Free Software Foundation'; either version 2, or (at your option)
+*  the `Free Software Foundation'; either version 3, or (at your option)
 *  any later version.
 *
 *  You should have received a copy of the `GNU General Public License'
 *  along with this program; if not, write to the:
 *
-*    Free Software Foundation, Inc.
-*    59 Temple Place - Suite 330
-*    Boston, MA 02111-1307,  USA
 */
 
 
@@ -36,9 +34,6 @@
 /*
 *  GLOBAL functions prototypes.
 */
-__BEGIN_DECLARATIONS
-EXPORT int
-main __P_((int   argc,
-           char *argv[]));
+__BEGIN_DECLARATIONS extern int main __P_ ((int argc, char *argv[]));
 __END_DECLARATIONS
 #endif /* __TXT2GCAL_H */
